/**
 * Renders a component to raw HTML (classic JSX runtime).
 *
 * @template {Record<string, unknown>} P
 * @param {string | Component<P>} type the type of the component to render
 * @param {Omit<P, "children"> | null | undefined} props the component's props
 * @param {unknown[]} children the component's children
 * @returns {RawHtml} the rendered component as raw HTML
 */
export function h<P extends Record<string, unknown>>(type: string | Component<P>, props: Omit<P, "children"> | null | undefined, ...children: unknown[]): RawHtml;
/**
 * Renders a component to raw HTML (automatic JSX runtime).
 *
 * @template {{}} P
 * @param {string | Component<P>} type the type of the
 * component to render
 * @param {P & { children?: unknown }} props the component's props, including
 * children
 * @returns {RawHtml} the rendered component as raw HTML
 */
export function jsx<P extends {}>(type: string | Component<P>, props: P & {
    children?: unknown;
}): RawHtml;
/**
 * @template {Record<string, unknown>} [P=Record<string, unknown>]
 * @typedef {(props: P) => RawHtml} Component
 */
/**
 * A wrapper around a string to indicate that it contains raw HTML, to be
 * treated literally (not escaped) when rendered.
 */
export class RawHtml {
    /**
     * Constructs a new instance using the given raw HTML.
     *
     * @param {string} html raw HTML
     */
    constructor(html: string);
    /**
     * The raw HTML as a string.
     *
     * @type {string}
     */
    html: string;
    toString(): string;
}
/** @type {Component<{ children?: unknown }>} */
export const Fragment: Component<{
    children?: unknown;
}>;
export type Component<P extends Record<string, unknown> = Record<string, unknown>> = (props: P) => RawHtml;
export { jsx as jsxs, jsx as jsxDev };

declare global {
  namespace JSX {
    interface IntrinsicElements {
      [elemName: string]: unknown;
    }

    type Element = RawHtml;

    interface ElementChildrenAttribute {
      children: unknown;
    }
  }
}
